# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/attribute.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/community/attribute.proto',
  package='eolymp.community',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/community;community',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/community/attribute.proto\x12\x10\x65olymp.community\"\xb6\x03\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x0b\x64\x65scription\x18\n \x03(\x0b\x32\'.eolymp.community.Attribute.Description\x12.\n\x04type\x18\x14 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\r\n\x05index\x18\x15 \x01(\r\x12\x10\n\x08required\x18\x1f \x01(\x08\x12\x0e\n\x06hidden\x18  \x01(\x08\x12\x0e\n\x06regexp\x18\x64 \x01(\t\x12\x0b\n\x03min\x18\x65 \x01(\x05\x12\x0b\n\x03max\x18\x66 \x01(\x05\x12\x0f\n\x07\x63hoices\x18g \x03(\t\x1a\\\n\x0b\x44\x65scription\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\"d\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\n\n\x06NUMBER\x10\x03\x12\n\n\x06\x43HOICE\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\t\n\x05\x45MAIL\x10\x06\x12\x0c\n\x08\x43HECKBOX\x10\x07\x42;Z9github.com/eolymp/contracts/go/eolymp/community;communityb\x06proto3'
)



_ATTRIBUTE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.community.Attribute.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHOICE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECKBOX', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=393,
  serialized_end=493,
)
_sym_db.RegisterEnumDescriptor(_ATTRIBUTE_TYPE)


_ATTRIBUTE_DESCRIPTION = _descriptor.Descriptor(
  name='Description',
  full_name='eolymp.community.Attribute.Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default', full_name='eolymp.community.Attribute.Description.default', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.community.Attribute.Description.locale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='eolymp.community.Attribute.Description.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='help', full_name='eolymp.community.Attribute.Description.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.community.Attribute.Description.choices', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=391,
)

_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='eolymp.community.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.community.Attribute.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='eolymp.community.Attribute.description', index=1,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.community.Attribute.type', index=2,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.community.Attribute.index', index=3,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.community.Attribute.required', index=4,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='eolymp.community.Attribute.hidden', index=5,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regexp', full_name='eolymp.community.Attribute.regexp', index=6,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='eolymp.community.Attribute.min', index=7,
      number=101, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='eolymp.community.Attribute.max', index=8,
      number=102, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.community.Attribute.choices', index=9,
      number=103, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTE_DESCRIPTION, ],
  enum_types=[
    _ATTRIBUTE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=493,
)

_ATTRIBUTE_DESCRIPTION.containing_type = _ATTRIBUTE
_ATTRIBUTE.fields_by_name['description'].message_type = _ATTRIBUTE_DESCRIPTION
_ATTRIBUTE.fields_by_name['type'].enum_type = _ATTRIBUTE_TYPE
_ATTRIBUTE_TYPE.containing_type = _ATTRIBUTE
DESCRIPTOR.message_types_by_name['Attribute'] = _ATTRIBUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Attribute = _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), {

  'Description' : _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
    'DESCRIPTOR' : _ATTRIBUTE_DESCRIPTION,
    '__module__' : 'eolymp.community.attribute_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.community.Attribute.Description)
    })
  ,
  'DESCRIPTOR' : _ATTRIBUTE,
  '__module__' : 'eolymp.community.attribute_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.community.Attribute)
  })
_sym_db.RegisterMessage(Attribute)
_sym_db.RegisterMessage(Attribute.Description)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/scoreboard.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ranker import format_pb2 as eolymp_dot_ranker_dot_format__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/ranker/scoreboard.proto',
  package='eolymp.ranker',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/ranker;ranker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/ranker/scoreboard.proto\x12\reolymp.ranker\x1a\x1a\x65olymp/ranker/format.proto\"\x94\x06\n\nScoreboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x06\x66ormat\x18\n \x01(\x0e\x32\x15.eolymp.ranker.Format\x1a\xb5\x02\n\x03Row\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x33\n\x06values\x18\x14 \x03(\x0b\x32#.eolymp.ranker.Scoreboard.Row.Value\x1a\xab\x01\n\x05Value\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x12\n\npercentage\x18\x0c \x01(\x02\x12\x10\n\x08\x61ttempts\x18\r \x01(\r\x12\x11\n\tsolved_in\x18\x0e \x01(\r\x12\x14\n\x0cvalue_string\x18\x14 \x01(\t\x12\x14\n\x0cvalue_number\x18\x15 \x01(\x05\x1a\xff\x02\n\x06\x43olumn\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x12\n\nshort_name\x18\x05 \x01(\t\x12\x33\n\x04type\x18\x06 \x01(\x0e\x32%.eolymp.ranker.Scoreboard.Column.Type\x12\r\n\x05index\x18\x07 \x01(\r\x12\x0f\n\x07visible\x18\x08 \x01(\x08\x12\x1d\n\x15\x63ontest_scoreboard_id\x18\x14 \x01(\t\x12\x1a\n\x12\x63ontest_problem_id\x18\x15 \x01(\t\x12\x1f\n\x17\x63ommunity_attribute_key\x18\x16 \x01(\t\x12\x31\n\x07\x63olumns\x18\x64 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"C\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43ONTEST\x10\x01\x12\x0b\n\x07PROBLEM\x10\x02\x12\r\n\tATTRIBUTE\x10\x03\x12\x08\n\x04NAME\x10\x04\x42\x35Z3github.com/eolymp/contracts/go/eolymp/ranker;rankerb\x06proto3'
  ,
  dependencies=[eolymp_dot_ranker_dot_format__pb2.DESCRIPTOR,])



_SCOREBOARD_COLUMN_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.ranker.Scoreboard.Column.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROBLEM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ATTRIBUTE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAME', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=799,
  serialized_end=866,
)
_sym_db.RegisterEnumDescriptor(_SCOREBOARD_COLUMN_TYPE)


_SCOREBOARD_ROW_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='eolymp.ranker.Scoreboard.Row.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.Scoreboard.Row.Value.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_id', full_name='eolymp.ranker.Scoreboard.Row.Value.column_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.ranker.Scoreboard.Row.Value.score', index=2,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.ranker.Scoreboard.Row.Value.penalty', index=3,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.ranker.Scoreboard.Row.Value.percentage', index=4,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='eolymp.ranker.Scoreboard.Row.Value.attempts', index=5,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved_in', full_name='eolymp.ranker.Scoreboard.Row.Value.solved_in', index=6,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_string', full_name='eolymp.ranker.Scoreboard.Row.Value.value_string', index=7,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_number', full_name='eolymp.ranker.Scoreboard.Row.Value.value_number', index=8,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=480,
)

_SCOREBOARD_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='eolymp.ranker.Scoreboard.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.Scoreboard.Row.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.Row.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.ranker.Scoreboard.Row.member_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.ranker.Scoreboard.Row.score', index=3,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.ranker.Scoreboard.Row.penalty', index=4,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='eolymp.ranker.Scoreboard.Row.values', index=5,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOREBOARD_ROW_VALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=480,
)

_SCOREBOARD_COLUMN = _descriptor.Descriptor(
  name='Column',
  full_name='eolymp.ranker.Scoreboard.Column',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.Scoreboard.Column.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='eolymp.ranker.Scoreboard.Column.parent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.ranker.Scoreboard.Column.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.Column.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_name', full_name='eolymp.ranker.Scoreboard.Column.short_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.ranker.Scoreboard.Column.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.ranker.Scoreboard.Column.index', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='eolymp.ranker.Scoreboard.Column.visible', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_scoreboard_id', full_name='eolymp.ranker.Scoreboard.Column.contest_scoreboard_id', index=8,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_problem_id', full_name='eolymp.ranker.Scoreboard.Column.contest_problem_id', index=9,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='community_attribute_key', full_name='eolymp.ranker.Scoreboard.Column.community_attribute_key', index=10,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='eolymp.ranker.Scoreboard.Column.columns', index=11,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCOREBOARD_COLUMN_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=866,
)

_SCOREBOARD = _descriptor.Descriptor(
  name='Scoreboard',
  full_name='eolymp.ranker.Scoreboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.Scoreboard.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.ranker.Scoreboard.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='eolymp.ranker.Scoreboard.format', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOREBOARD_ROW, _SCOREBOARD_COLUMN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=866,
)

_SCOREBOARD_ROW_VALUE.containing_type = _SCOREBOARD_ROW
_SCOREBOARD_ROW.fields_by_name['values'].message_type = _SCOREBOARD_ROW_VALUE
_SCOREBOARD_ROW.containing_type = _SCOREBOARD
_SCOREBOARD_COLUMN.fields_by_name['type'].enum_type = _SCOREBOARD_COLUMN_TYPE
_SCOREBOARD_COLUMN.fields_by_name['columns'].message_type = _SCOREBOARD_COLUMN
_SCOREBOARD_COLUMN.containing_type = _SCOREBOARD
_SCOREBOARD_COLUMN_TYPE.containing_type = _SCOREBOARD_COLUMN
_SCOREBOARD.fields_by_name['format'].enum_type = eolymp_dot_ranker_dot_format__pb2._FORMAT
DESCRIPTOR.message_types_by_name['Scoreboard'] = _SCOREBOARD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scoreboard = _reflection.GeneratedProtocolMessageType('Scoreboard', (_message.Message,), {

  'Row' : _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {

    'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
      'DESCRIPTOR' : _SCOREBOARD_ROW_VALUE,
      '__module__' : 'eolymp.ranker.scoreboard_pb2'
      # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Row.Value)
      })
    ,
    'DESCRIPTOR' : _SCOREBOARD_ROW,
    '__module__' : 'eolymp.ranker.scoreboard_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Row)
    })
  ,

  'Column' : _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), {
    'DESCRIPTOR' : _SCOREBOARD_COLUMN,
    '__module__' : 'eolymp.ranker.scoreboard_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Column)
    })
  ,
  'DESCRIPTOR' : _SCOREBOARD,
  '__module__' : 'eolymp.ranker.scoreboard_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard)
  })
_sym_db.RegisterMessage(Scoreboard)
_sym_db.RegisterMessage(Scoreboard.Row)
_sym_db.RegisterMessage(Scoreboard.Row.Value)
_sym_db.RegisterMessage(Scoreboard.Column)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class UniverseClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateSpace(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/CreateSpace",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.CreateSpaceOutput"),
            **kwargs,
        )

    def UpdateSpace(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/UpdateSpace",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.UpdateSpaceOutput"),
            **kwargs,
        )

    def DeleteSpace(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/DeleteSpace",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.DeleteSpaceOutput"),
            **kwargs,
        )

    def LookupSpace(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/LookupSpace",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.LookupSpaceOutput"),
            **kwargs,
        )

    def DescribeSpace(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/DescribeSpace",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.DescribeSpaceOutput"),
            **kwargs,
        )

    def DescribeQuota(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/DescribeQuota",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.DescribeQuotaOutput"),
            **kwargs,
        )

    def ListSpaces(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/ListSpaces",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.ListSpacesOutput"),
            **kwargs,
        )

    def GrantPermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/GrantPermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.GrantPermissionOutput"),
            **kwargs,
        )

    def RevokePermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/RevokePermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.RevokePermissionOutput"),
            **kwargs,
        )

    def DescribePermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/DescribePermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.DescribePermissionOutput"),
            **kwargs,
        )

    def IntrospectPermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/IntrospectPermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.IntrospectPermissionOutput"),
            **kwargs,
        )

    def ListPermissions(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.universe.Universe/ListPermissions",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.universe.ListPermissionsOutput"),
            **kwargs,
        )

